@@ -27,9 +27,9 @@
 
 #include "kcmoduleqml_p.h"
 #include "kcmoduleproxy.h"
+#include <kcmutils_debug.h>
 
 #include <QApplication>
-#include <QDebug>
 #include <QDesktopServices>
 #include <QDesktopWidget>
 #include <QLayout>
@@ -49,6 +49,7 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KPageWidgetModel>
+#include <KPluginInfo>
 
 bool KCMultiDialogPrivate::resolveChanges(KCModuleProxy *currentProxy)
 {
@@ -88,16 +89,11 @@ void KCMultiDialogPrivate::_k_slotCurrentPageChanged(KPageWidgetItem *current, K
 {
     Q_Q(KCMultiDialog);
 
-
-    KCModuleProxy *currentModule = nullptr;
     KCModuleProxy *previousModule = nullptr;
     for (int i = 0; i < modules.count(); ++i) {
         if (modules[i].item == previous) {
             previousModule = modules[i].kcm;
         }
-        if (modules[i].item == current) {
-            currentModule = modules[i].kcm;
-        }
     }
 
     // Remove margins for the buttonbox; KPageDialog handles that already
@@ -106,8 +102,6 @@ void KCMultiDialogPrivate::_k_slotCurrentPageChanged(KPageWidgetItem *current, K
     q->blockSignals(true);
     q->setCurrentPage(previous);
 
-
-
     if (resolveChanges(previousModule)) {
         q->setCurrentPage(current);
     }
@@ -181,7 +175,7 @@ void KCMultiDialogPrivate::_k_clientChanged()
 #endif
     }
 
-    auto buttons = activeModule->buttons();
+    auto buttons = activeModule ? activeModule->buttons() : KCModule::NoAdditionalButton;
 
     QPushButton *resetButton = q->buttonBox()->button(QDialogButtonBox::Reset);
     if (resetButton) {
@@ -470,13 +464,13 @@ KPageWidgetItem *KCMultiDialog::addModule(const KCModuleInfo &moduleInfo,
         KPageWidgetItem *parentItem, const QStringList &args)
 {
     Q_D(KCMultiDialog);
-    if (!moduleInfo.service()) {
+    if (!moduleInfo.isValid()) {
         return nullptr;
     }
 
     //KAuthorized::authorizeControlModule( moduleInfo.service()->menuId() ) is
     //checked in noDisplay already
-    if (moduleInfo.service()->noDisplay()) {
+    if (moduleInfo.service() && moduleInfo.service()->noDisplay()) {
         return nullptr;
     }
 
@@ -496,7 +490,7 @@ KPageWidgetItem *KCMultiDialog::addModule(const KCModuleInfo &moduleInfo,
     KCMultiDialogPrivate::CreatedModule cm;
     cm.kcm = kcm;
     cm.item = item;
-    cm.componentNames = moduleInfo.service()->property(QStringLiteral("X-KDE-ParentComponents")).toStringList();
+    cm.componentNames = moduleInfo.property(QStringLiteral("X-KDE-ParentComponents")).toStringList();
     d->modules.append(cm);
 
     if (qobject_cast<KCModuleQml *>(kcm->realModule())) {
