@@ -18,16 +18,17 @@
 */
 
 #include "componentsdialog_p.h"
-#include <klocalizedstring.h>
+#include <kcmutils_debug.h>
+
+#include <KLocalizedString>
 #include <QDialogButtonBox>
 #include <QLabel>
 #include <QPushButton>
-#include <kplugininfo.h>
-#include <QDebug>
+#include <KPluginInfo>
 #include <QVBoxLayout>
 #include <QHBoxLayout>
-#include <kconfig.h>
-#include <kseparator.h>
+#include <KConfig>
+#include <KSeparator>
 
 #include <QList>
 #include <QTreeWidget>
